@@ -23,6 +23,9 @@
 #include <openjij/utility/gpu/memory.hpp>
 #include <openjij/utility/gpu/cublas.hpp>
 
+#include <Eigen/Dense>
+#include <Eigen/Sparse>
+
 #include "polynomial_test.hpp"
 
 // #####################################
@@ -217,11 +220,19 @@ TEST(Graph, EnergyCheck){
         }
     }
 
+    // generate interaction matrix from dense graph
+    Eigen::SparseMatrix<double, Eigen::RowMajor> mat = b_d.get_interactions().sparseView();
+    // and generate CSRSparse
+    CSRSparse<double> b_csrs(mat.template triangularView<Eigen::Upper>());
+
     EXPECT_EQ(b_d.calc_energy(spins), (1./2) * (N*N - N));
     EXPECT_EQ(b_d.calc_energy(spins_neg), (1./2) * (N*N - N));
     EXPECT_EQ(b.calc_energy(spins), (1./2) * (N*N - N));
     EXPECT_EQ(b.calc_energy(spins_neg), (1./2) * (N*N - N));
+    EXPECT_EQ(b_csrs.calc_energy(spins), (1./2) * (N*N - N));
+    EXPECT_EQ(b_csrs.calc_energy(spins_neg), (1./2) * (N*N - N));
     EXPECT_EQ(b_d.calc_energy(spins_r), b.calc_energy(spins_r));
+    EXPECT_EQ(b_d.calc_energy(spins_r), b_csrs.calc_energy(spins_r));
 
     Dense<double> c_d(N);
     Sparse<double> c(N, N);
@@ -237,12 +248,19 @@ TEST(Graph, EnergyCheck){
             c.J(i, j) = 1;
         }
     }
+    // generate interaction matrix from dense graph
+    mat = c_d.get_interactions().sparseView();
+    // and generate CSRSparse
+    CSRSparse<double> c_csrs(mat.template triangularView<Eigen::Upper>());
 
     EXPECT_EQ(c_d.calc_energy(spins), (1./2) * (N*N + N));
     EXPECT_EQ(c_d.calc_energy(spins_neg), (1./2) * (N*N - 3*N));
     EXPECT_EQ(c.calc_energy(spins), (1./2) * (N*N + N));
     EXPECT_EQ(c.calc_energy(spins_neg), (1./2) * (N*N - 3*N));
+    EXPECT_EQ(c_csrs.calc_energy(spins), (1./2) * (N*N + N));
+    EXPECT_EQ(c_csrs.calc_energy(spins_neg), (1./2) * (N*N - 3*N));
     EXPECT_EQ(c_d.calc_energy(spins_r), c.calc_energy(spins_r));
+    EXPECT_EQ(c_d.calc_energy(spins_r), c_csrs.calc_energy(spins_r));
 }
 
 //json tests
@@ -328,6 +346,26 @@ TEST(SingleSpinFlip, FindTrueGroundState_ClassicalIsing_Sparse) {
     EXPECT_EQ(get_true_groundstate(), result::get_solution(classical_ising));
 }
 
+TEST(SingleSpinFlip, FindTrueGroundState_ClassicalIsing_CSRSparse) {
+    using namespace openjij;
+
+    //generate classical dense system
+    const auto dense_interaction = generate_interaction<graph::Dense<double>>();
+    //output sparse interaction
+    Eigen::SparseMatrix<double, Eigen::RowMajor> sp_mat = dense_interaction.get_interactions().sparseView();
+    const auto interaction = graph::CSRSparse<double>(sp_mat.template triangularView<Eigen::Upper>());
+    auto engine_for_spin = std::mt19937(1);
+    const auto spin = interaction.gen_spin(engine_for_spin);
+    auto classical_ising = system::make_classical_ising(spin, interaction);
+    
+    auto random_numder_engine = std::mt19937(1);
+    const auto schedule_list = generate_schedule_list();
+
+    algorithm::Algorithm<updater::SingleSpinFlip>::run(classical_ising, random_numder_engine, schedule_list);
+
+    EXPECT_EQ(get_true_groundstate(), result::get_solution(classical_ising));
+}
+
 TEST(SingleSpinFlip, FindTrueGroundState_TransverseIsing_Dense) {
     using namespace openjij;
 
@@ -378,6 +416,33 @@ TEST(SingleSpinFlip, FindTrueGroundState_TransverseIsing_Sparse) {
     EXPECT_EQ(get_true_groundstate(), result::get_solution(transverse_ising));
 }
 
+TEST(SingleSpinFlip, FindTrueGroundState_TransverseIsing_CSRSparse) {
+    using namespace openjij;
+
+    //generate classical dense system
+    const auto dense_interaction = generate_interaction<graph::Dense<double>>();
+    //output sparse interaction
+    Eigen::SparseMatrix<double, Eigen::RowMajor> sp_mat = dense_interaction.get_interactions().sparseView();
+    const auto interaction = graph::CSRSparse<double>(sp_mat.template triangularView<Eigen::Upper>());
+    auto engine_for_spin = std::mt19937(1);
+    std::size_t num_trotter_slices = 10;
+
+    //generate random trotter spins
+    system::TrotterSpins init_trotter_spins(num_trotter_slices);
+    for(auto& spins : init_trotter_spins){
+        spins = interaction.gen_spin(engine_for_spin);
+    }
+
+    auto transverse_ising = system::make_transverse_ising(init_trotter_spins, interaction, 1.0); //gamma = 1.0
+    
+    auto random_numder_engine = std::mt19937(1);
+    const auto schedule_list = generate_tfm_schedule_list();
+
+    algorithm::Algorithm<updater::SingleSpinFlip>::run(transverse_ising, random_numder_engine, schedule_list);
+
+    EXPECT_EQ(get_true_groundstate(), result::get_solution(transverse_ising));
+}
+
 
 
 ///-------------------------------------------------------------------------------------------
